Documentation
¶
Index ¶
- func HashPackages(packages []string) string
- func IsPackageInstallHit(dir string) bool
- type Cache
- func (c *Cache) BaseDir() string
- func (c *Cache) BunDir() string
- func (c *Cache) CleanAll() error
- func (c *Cache) CleanBun() error
- func (c *Cache) CleanDeps() error
- func (c *Cache) CleanIndex() error
- func (c *Cache) CleanTypecheck() error
- func (c *Cache) DepsDir() string
- func (c *Cache) DepsDirForHash(hash string) string
- func (c *Cache) EnsureDirs() error
- func (c *Cache) IndexDir() string
- func (c *Cache) IsDepsHit(hash string) bool
- func (c *Cache) ListBunVersions() ([]string, error)
- func (c *Cache) ListDepsHashes() ([]string, error)
- func (c *Cache) ListTypecheckHashes() ([]string, error)
- func (c *Cache) Size() (int64, error)
- func (c *Cache) TypecheckDir() string
- func (c *Cache) TypecheckDirForHash(hash string) string
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func HashPackages ¶
HashPackages creates a cache key from a list of packages
func IsPackageInstallHit ¶ added in v1.0.0
IsPackageInstallHit checks if a dependency directory contains installed packages
Types ¶
type Cache ¶
type Cache struct {
// contains filtered or unexported fields
}
Cache manages the buns cache directory
func (*Cache) CleanTypecheck ¶ added in v1.0.0
CleanTypecheck removes all cached typecheck dependencies
func (*Cache) DepsDirForHash ¶
DepsDirForHash returns the directory for a specific dependency hash
func (*Cache) EnsureDirs ¶
EnsureDirs creates all necessary cache directories
func (*Cache) ListBunVersions ¶
ListBunVersions returns all cached Bun versions
func (*Cache) ListDepsHashes ¶
ListDepsHashes returns all cached dependency hashes
func (*Cache) ListTypecheckHashes ¶ added in v1.0.0
ListTypecheckHashes returns all cached typecheck dependency hashes
func (*Cache) TypecheckDir ¶ added in v1.0.0
TypecheckDir returns the directory for typecheck dependencies
func (*Cache) TypecheckDirForHash ¶ added in v1.0.0
TypecheckDirForHash returns the directory for a specific typecheck dependency hash