package
Version:
v1.0.0
Opens a new window with list of versions in this module.
Published: May 21, 2026
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Metadata struct {
Bun string `toml:"bun"`
Packages []string `toml:"packages"`
}
Metadata represents the parsed // buns block from a script
Parse extracts metadata from a script's // buns comment block
Source Files
¶
Click to show internal directories.
Click to hide internal directories.