Documentation
¶
Index ¶
- func HashPackages(packages []string) string
- type Cache
- func (c *Cache) BaseDir() string
- func (c *Cache) BunDir() string
- func (c *Cache) CleanAll() error
- func (c *Cache) CleanBun() error
- func (c *Cache) CleanDeps() error
- func (c *Cache) CleanIndex() error
- func (c *Cache) DepsDir() string
- func (c *Cache) DepsDirForHash(hash string) string
- func (c *Cache) EnsureDirs() error
- func (c *Cache) IndexDir() string
- func (c *Cache) IsDepsHit(hash string) bool
- func (c *Cache) ListBunVersions() ([]string, error)
- func (c *Cache) ListDepsHashes() ([]string, error)
- func (c *Cache) Size() (int64, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func HashPackages ¶
HashPackages creates a cache key from a list of packages
Types ¶
type Cache ¶
type Cache struct {
// contains filtered or unexported fields
}
Cache manages the buns cache directory
func (*Cache) DepsDirForHash ¶
DepsDirForHash returns the directory for a specific dependency hash
func (*Cache) EnsureDirs ¶
EnsureDirs creates all necessary cache directories
func (*Cache) ListBunVersions ¶
ListBunVersions returns all cached Bun versions
func (*Cache) ListDepsHashes ¶
ListDepsHashes returns all cached dependency hashes
Click to show internal directories.
Click to hide internal directories.